importance: Variable Importance for SCE and SCA Models

View source: R/SCE.R

importanceR Documentation

Variable Importance for SCE and SCA Models

Description

Calculate variable importance for SCE or SCA models.

Usage

## S3 method for class 'sce'
importance(object, oob_weight = TRUE, digits = 2, ...)
## S3 method for class 'sca'
importance(object, digits = 2, ...)

Arguments

object

An SCE or SCA model object

oob_weight

Use out-of-bag weights for importance calculation (SCE only, default: TRUE)

digits

Number of decimal places to round the returned relative importance values (default: 2)

...

Additional arguments

Value

Variable importance rankings. For convenience, relative importance values are rounded to digits decimal places.

See Also

sce, sca, rfe_sce


SCE documentation built on May 11, 2026, 9:07 a.m.