print: Print SCE and SCA Model Objects

printR Documentation

Print SCE and SCA Model Objects

Description

Print information about SCE or SCA model objects.

Usage

## S3 method for class 'sce'
print(x, ...)
## S3 method for class 'sca'
print(x, ...)

Arguments

x

An SCE or SCA model object

...

Additional arguments (not used)

Details

For SCE objects, prints ensemble information including number of trees, parameters, predictors, predictants, and OOB performance metrics.

For SCA objects, prints tree structure information including total nodes, leaf nodes, cutting/merging actions, and variable names.

Value

Prints model information and returns the object invisibly.

See Also

sce, sca, summary


SCE documentation built on May 11, 2026, 9:07 a.m.

Related to print in SCE...