| summary | R Documentation |
Provide concise summaries of model structure and performance for SCE and SCA objects.
## S3 method for class 'sce'
summary(object, ...)
## S3 method for class 'sca'
summary(object, ...)
object |
An SCE or SCA model object |
... |
Additional arguments passed to or ignored by methods |
For summary.sce, the method prints ensemble configuration, out-of-bag (OOB) performance statistics, tree structure information, and tree weight distribution.\
For summary.sca, the method prints tree structure information and variable summaries for the single SCA tree.
Invisibly returns the input object after printing the summary.
sce, sca, print, importance, evaluate
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.