| importance | R Documentation |
Calculate variable importance for SCE or SCA models.
## S3 method for class 'sce'
importance(object, oob_weight = TRUE, digits = 2, ...)
## S3 method for class 'sca'
importance(object, digits = 2, ...)
object |
An SCE or SCA model object |
oob_weight |
Use out-of-bag weights for importance calculation (SCE only, default: TRUE) |
digits |
Number of decimal places to round the returned relative importance values (default: 2) |
... |
Additional arguments |
Variable importance rankings. For convenience, relative importance values are rounded to digits decimal places.
sce, sca, rfe_sce
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.