| R Documentation |
Print information about SCE or SCA model objects.
## S3 method for class 'sce'
print(x, ...)
## S3 method for class 'sca'
print(x, ...)
x |
An SCE or SCA model object |
... |
Additional arguments (not used) |
For SCE objects, prints ensemble information including number of trees, parameters, predictors, predictants, and OOB performance metrics.
For SCA objects, prints tree structure information including total nodes, leaf nodes, cutting/merging actions, and variable names.
Prints model information and returns the object invisibly.
sce, sca, summary
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.